@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.525-10-g2613da3e
+package JSON::Schema::Modern; # git description: v0.526-10-g2a71a34d
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema data validation structure specification
 
-our $VERSION = '0.526';
+our $VERSION = '0.527';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -146,7 +146,7 @@ sub add_schema {
     );
 
   croak(!(caller())[0]->isa(__PACKAGE__)
-    ? join('; ', map $_->keyword_location.': '.$_->error, $document->errors)
+    ? join("\n", $document->errors)
     : JSON::Schema::Modern::Result->new(
       output_format => $self->output_format,
       valid => 0,
@@ -412,6 +412,7 @@ sub _traverse_subschema ($self, $schema, $state) {
   return E($state, 'invalid schema type: %s', $schema_type) if $schema_type ne 'object';
 
   my $valid = 1;
+  # we must check the array length on every iteration because some keywords can change it!
   for (my $idx = 0; $idx <= $state->{vocabularies}->$#*; ++$idx) {
     my $vocabulary = $state->{vocabularies}[$idx];
     foreach my $keyword ($vocabulary->keywords($state->{spec_version})) {
@@ -830,8 +831,9 @@ has _media_type => (
   lazy => 1,
   default => sub ($self) {
     +{
+      # note: utf-8 decoding is NOT done, as we can't be sure that's the correct charset!
       'application/json' => sub ($content_ref) {
-        \ JSON::MaybeXS->new(allow_nonref => 1, utf8 => 1)->decode($content_ref->$*);
+        \ JSON::MaybeXS->new(allow_nonref => 1, utf8 => 0)->decode($content_ref->$*);
       },
       'text/plain' => sub ($content_ref) { $content_ref }
     };
@@ -850,7 +852,8 @@ has _encoding => (
   default => sub ($self) {
     +{
       'base64' => sub ($content_ref) {
-        die "invalid characters in base64 string" if $content_ref->$* =~ m{[^A-Za-z0-9+/]};
+        die "invalid characters in base64 string"
+          if $content_ref->$* =~ m{[^A-Za-z0-9+/=]} or $content_ref->$* =~ m{=(?=[^=])};
         require MIME::Base64; \ MIME::Base64::decode($content_ref->$*);
       },
     };
@@ -873,7 +876,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.526
+version 0.527
 
 =head1 SYNOPSIS
 
@@ -1024,8 +1027,9 @@ or a URI string indicating the location where such a schema is located.
 =back
 
 Optionally, a hashref can be passed as a third parameter which allows changing the values of the
-L</short_circuit>, L</collect_annotations>, L</annotate_unknown_keywords>, L</scalarref_booleans> and/or
-L</validate_formats> settings for just this evaluation call.
+L</short_circuit>, L</collect_annotations>, L</annotate_unknown_keywords>, L</scalarref_booleans>,
+L</validate_formats>, and/or L<validate_content_schemas>
+settings for just this evaluation call.
 
 The result is a L<JSON::Schema::Modern::Result> object, which can also be used as a boolean.
 
@@ -1058,9 +1062,9 @@ or a URI string indicating the location where such a schema is located.
 =back
 
 Optionally, a hashref can be passed as a third parameter which allows changing the values of the
-L</short_circuit>, L</collect_annotations>, L</annotate_unknown_keywords>, L</scalarref_booleans> and/or
-L</validate_formats>, L<validate_content_schemas> settings for just this
-evaluation call.
+L</short_circuit>, L</collect_annotations>, L</annotate_unknown_keywords>, L</scalarref_booleans>,
+L</validate_formats>, and/or L<validate_content_schemas>
+settings for just this evaluation call.
 
 You can pass a series of callback subs to this method corresponding to keywords, which is useful for
 identifying various data that are not exposed by annotations.
@@ -1182,7 +1186,7 @@ You can use it thusly:
 
 Takes an encoding name and a subref which takes a single scalar reference, which is expected to be
 a reference to a string, which SHOULD be a 7-bit or 8-bit string. Result values MUST be a scalar-reference
-to a string.
+to a string (which is then dereferenced for the C<contentMediaType> keyword).
 
 =for stopwords natively
 
@@ -1339,7 +1343,8 @@ C<idn-hostname> requires L<Net::IDN::Encode>
 
 =head2 Specification Compliance
 
-This implementation is now fully specification-compliant, but until version 1.000 is released, it is
+This implementation is now fully specification-compliant (for versions draft7, draft2019-09,
+draft2020-12), but until version 1.000 is released, it is
 still deemed to be missing some optional but quite useful features, such as:
 
 =over 4
